Welcome to MyTB (My Toolbox)

MyTB is just another collection of handy and useful python functions and modules.

version 0.1 is only python 3 compatible
use `pip install 'mytb<0.1'` to get the last python2 compatible version

.. image:: https://travis-ci.com/feenes/mytb.svg?branch=master
    :target: https://travis-ci.com/feenes/mytb


It can be found at https://github.com/feenes/mytb.git

It tries to be modular in order to consume as little memory (RAM) as possible.
